# ODP Python SDK

Connect to the Ocean Data Platform with Python through the Python SDK. Download queried ocean data easily and efficiently into data frames, for easy exploring and further processing in your data science project.

## Documentation

https://docs.hubocea.earth

## Installation

```shell
pip install odp-sdk
```